@@ -13,7 +13,7 @@
 #' @importFrom yardstick rsq rmse accuracy roc_auc
 #' @importFrom tidyr unnest nest
 #' @importFrom GPfit GP_fit
-#' @importFrom parsnip get_from_env
+#' @importFrom parsnip get_from_env required_pkgs
 #' @importFrom recipes all_predictors all_outcomes
 #' @importFrom ggplot2 ggplot aes xlab geom_point geom_errorbar facet_wrap ylab
 #' @importFrom ggplot2 facet_grid geom_line aes_string aes_
@@ -32,7 +32,8 @@
 # ------------------------------------------------------------------------------
 
 utils::globalVariables(
-  c("engine", "name", "func", "parsnip", "call_name", ".step", "call_info",
+  c(
+    "engine", "name", "func", "parsnip", "call_name", ".step", "call_info",
     "component", "component_id", "id", "control", ".pred", ".metric",
     ".estimator", ".estimate", "n", "note", "object", "splits", "grid",
     "resamples", ".iter", "mean", ".submodels", "metrics", "data", ".mean",
@@ -41,8 +42,9 @@ utils::globalVariables(
     ".extracts", ".metrics", "value", ".notes", ".loss", ".bound",
     ".column", ".totals", ".value", "direction", ".config", "Freq", "Prediction",
     "Truth", ".seed", ".order", ".iter_model", ".iter_preprocessor",
-    ".iter_config", ".msg_model", "# resamples", "seed")
+    ".iter_config", ".msg_model", "# resamples", "seed", "pre", "type"
   )
+)
 
 # ------------------------------------------------------------------------------
 
