@@ -3,17 +3,18 @@
 #' @rdname empty_ellipses
 check_rset <- function(x) {
   if (!inherits(x, "rset")) {
-    stop("The `resamples` argument should be an 'rset' object, such as the type ",
-         "produced by `vfold_cv()` or other 'rsample' functions.",
-         call. = FALSE)
+    rlang::abort(paste0(
+      "The `resamples` argument should be an 'rset' object, such as the type ",
+      "produced by `vfold_cv()` or other 'rsample' functions."
+    ))
   }
   if (inherits(x, "loo_cv")) {
-    stop("Leave-one-out cross-validation is not currently supported with tune.",
-         call. = FALSE)
+    rlang::abort(
+      "Leave-one-out cross-validation is not currently supported with tune."
+    )
   }
   if (inherits(x, "nested_cv")) {
-    stop("Nested resampling is not currently supported with tune.",
-         call. = FALSE)
+    rlang::abort("Nested resampling is not currently supported with tune.")
   }
   invisible(NULL)
 }
@@ -28,7 +29,7 @@ check_grid <- function(grid, workflow, pset = NULL) {
   }
 
   if (is.null(pset)) {
-    pset <- dials::parameters(workflow)
+    pset <- hardhat::extract_parameter_set_dials(workflow)
   }
 
   if (nrow(pset) == 0L) {
@@ -113,7 +114,7 @@ needs_finalization <- function(x, nms = character(0)) {
   # no need for finalization
   x <- x[!is.na(x$object), ]
   # If the parameter is in a pre-defined grid, then no need to finalize
-  x <- x[!(x$id %in% nms),]
+  x <- x[!(x$id %in% nms), ]
   if (length(x) == 0) {
     return(FALSE)
   }
@@ -122,7 +123,7 @@ needs_finalization <- function(x, nms = character(0)) {
 
 check_parameters <- function(workflow, pset = NULL, data, grid_names = character(0)) {
   if (is.null(pset)) {
-    pset <- parameters(workflow)
+    pset <- hardhat::extract_parameter_set_dials(workflow)
   }
   unk <- purrr::map_lgl(pset$object, dials::has_unknowns)
   if (!any(unk)) {
@@ -169,7 +170,6 @@ is_installed <- function(pkg) {
 }
 
 check_installs <- function(x) {
-
   if (x$engine == "unknown") {
     rlang::abort("Please declare an engine for the model")
   } else {
@@ -182,33 +182,38 @@ check_installs <- function(x) {
   if (length(deps) > 0) {
     is_inst <- purrr::map_lgl(deps, is_installed)
     if (any(!is_inst)) {
-      stop("Some package installs are required: ",
-           paste0("'", deps[!is_inst], "'", collapse = ", "),
-           call. = FALSE
-      )
+      rlang::abort(c("Some package installs are required: ",
+                     paste0("'", deps[!is_inst], "'", collapse = ", ")
+      ))
     }
   }
 }
 
 check_bayes_initial_size <- function(num_param, num_grid, race = FALSE) {
   chr_param <-
-    ifelse(num_param == 1,
-           "is one tuning parameter",
-           paste("are", num_param, "tuning parameters"))
+    ifelse(
+      num_param == 1,
+      "is one tuning parameter",
+      paste("are", num_param, "tuning parameters")
+    )
   chr_grid <-
     ifelse(num_grid == 1,
            "a single grid point was",
-           paste(num_grid, "grid points were"))
+           paste(num_grid, "grid points were")
+    )
   msg <- paste0("There ", chr_param, " and ", chr_grid, " requested.")
   race_msg <-
     ifelse(race,
            "With racing, only completely resampled parameters are used.",
-           "")
+           ""
+    )
   if (num_grid == 1) {
     rlang::abort(
-      paste(tune_color$symbol$warning("!"), msg,
-            "The GP model requires 2+ initial points but there should",
-            "be more initial points than there are tuning paramters.", race_msg)
+      paste(
+        tune_color$symbol$warning("!"), msg,
+        "The GP model requires 2+ initial points but there should",
+        "be more initial points than there are tuning paramters.", race_msg
+      )
     )
   }
   if (num_grid < num_param + 1) {
@@ -256,7 +261,7 @@ check_workflow <- function(x, pset = NULL, check_dials = FALSE) {
 
   if (check_dials) {
     if (is.null(pset)) {
-      pset <- dials::parameters(x)
+      pset <- hardhat::extract_parameter_set_dials(x)
     }
 
     check_param_objects(pset)
@@ -285,18 +290,17 @@ check_metrics <- function(x, object) {
   mode <- extract_spec_parsnip(object)$mode
 
   if (is.null(x)) {
-    switch(
-      mode,
-      regression = {
-        x <- yardstick::metric_set(rmse, rsq)
-      },
-      classification = {
-        x <- yardstick::metric_set(roc_auc, accuracy)
-      },
-      unknown = {
-        rlang::abort("Internal error: `check_installs()` should have caught an `unknown` mode.")
-      },
-      rlang::abort("Unknown `mode` for parsnip model.")
+    switch(mode,
+           regression = {
+             x <- yardstick::metric_set(rmse, rsq)
+           },
+           classification = {
+             x <- yardstick::metric_set(roc_auc, accuracy)
+           },
+           unknown = {
+             rlang::abort("Internal error: `check_installs()` should have caught an `unknown` mode.")
+           },
+           rlang::abort("Unknown `mode` for parsnip model.")
     )
 
     return(x)
@@ -394,7 +398,8 @@ check_initial <- function(x, pset, wflow, resamples, metrics, ctrl, checks = "gr
     }
     if (any(checks == "bayes")) {
       check_bayes_initial_size(length(param_nms), num_grid,
-                               race = inherits(x, "tune_race"))
+                               race = inherits(x, "tune_race")
+      )
     }
   }
   if (!any(names(x) == ".iter")) {
@@ -419,7 +424,7 @@ get_objective_name <- function(x, metrics) {
 
 check_direction <- function(x) {
   if (!is.logical(x) || length(x) != 1) {
-    stop("`maximize` should be a single logical.", call. = FALSE)
+    rlang::abort("`maximize` should be a single logical.")
   }
   invisible(NULL)
 }
@@ -427,7 +432,7 @@ check_direction <- function(x) {
 
 check_best <- function(x) {
   if (!is.numeric(x) || length(x) != 1 || is.na(x)) {
-    stop("`best` should be a single, non-missing numeric", call. = FALSE)
+    rlang::abort("`best` should be a single, non-missing numeric.")
   }
   invisible(NULL)
 }
@@ -478,3 +483,53 @@ val_class_and_single <- function(x, cls = "numeric", where = NULL) {
   }
   invisible(NULL)
 }
+
+
+# Check the data going into the GP. If there are all missing values, fail. If some
+# are missing, remove them and send a warning. If all metrics are the same, fail.
+check_gp_data <- function(x) {
+  met <- x$.metric[[1]]
+
+  miss_y <- sum(is.nan(x$mean))
+  if (miss_y > 0) {
+    if (miss_y == nrow(x)) {
+      msg <- cli::pluralize(
+        "All of the {met} estimates were missing. The Gaussian process model cannot be fit to the data."
+      )
+      message_wrap(msg, prefix = "!", color_text = get_tune_colors()$message$danger)
+    } else {
+      msg <- cli::pluralize(
+        "For the {met} estimates, {miss_y} missing {?value was/values were} found and removed before fitting the Gaussian process model."
+      )
+      message_wrap(msg, prefix = "!", color_text = get_tune_colors()$message$warning)
+    }
+
+    x <- x[!is.na(x$mean), ]
+  }
+
+  n_uni <- length(unique(x$mean))
+  if (n_uni == 1) {
+    msg <- glue::glue(
+      "All of the {met} values were identical. The Gaussian process model cannot
+     be fit to the data. Try expanding the range of the tuning parameters."
+    )
+    message_wrap(msg, prefix = "!", color_text = get_tune_colors()$message$danger)
+  }
+
+  x
+}
+
+# If the current GP failed, use a previous one if it exists
+check_gp_failure <- function(current, prev) {
+  if (inherits(current, "GP")) {
+    return(current)
+  }
+
+  # first model failed or all previous models failed
+  if (is.null(prev) || inherits(prev, "try-error")) {
+    rlang::abort("Gaussian process model was not fit.")
+  }
+
+  # return prev model
+  prev
+}
